==> cdktf-cdktf-provider-opentelekomcloud-0.3.20.tar.gz: package/lib/data-opentelekomcloud-vpc-bandwidth-v2.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataOpentelekomcloudVpcBandwidthV2Config extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/opentelekomcloud/d/vpc_bandwidth_v2#name DataOpentelekomcloudVpcBandwidthV2#name}
    */
    readonly name?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/opentelekomcloud/d/vpc_bandwidth_v2#size DataOpentelekomcloudVpcBandwidthV2#size}
    */
    readonly size?: number;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/opentelekomcloud/d/vpc_bandwidth_v2 opentelekomcloud_vpc_bandwidth_v2}
*/
export declare class DataOpentelekomcloudVpcBandwidthV2 extends cdktf.TerraformDataSource {
    static readonly tfResourceType: string;
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/opentelekomcloud/d/vpc_bandwidth_v2 opentelekomcloud_vpc_bandwidth_v2} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataOpentelekomcloudVpcBandwidthV2Config = {}
    */
    constructor(scope: Construct, id: string, config?: DataOpentelekomcloudVpcBandwidthV2Config);
    get bandwidthType(): string;
    get chargeMode(): string;
    get id(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    get shareType(): string;
    private _size?;
    get size(): number;
    set size(value: number);
    resetSize(): void;
    get sizeInput(): number | undefined;
    get status(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf-cdktf-provider-opentelekomcloud-0.5.33.tar.gz: package/lib/data-opentelekomcloud-vpc-bandwidth-v2.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataOpentelekomcloudVpcBandwidthV2Config extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/opentelekomcloud/d/vpc_bandwidth_v2#id DataOpentelekomcloudVpcBandwidthV2#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/opentelekomcloud/d/vpc_bandwidth_v2#name DataOpentelekomcloudVpcBandwidthV2#name}
    */
    readonly name?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/opentelekomcloud/d/vpc_bandwidth_v2#size DataOpentelekomcloudVpcBandwidthV2#size}
    */
    readonly size?: number;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/opentelekomcloud/d/vpc_bandwidth_v2 opentelekomcloud_vpc_bandwidth_v2}
*/
export declare class DataOpentelekomcloudVpcBandwidthV2 extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "opentelekomcloud_vpc_bandwidth_v2";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/opentelekomcloud/d/vpc_bandwidth_v2 opentelekomcloud_vpc_bandwidth_v2} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataOpentelekomcloudVpcBandwidthV2Config = {}
    */
    constructor(scope: Construct, id: string, config?: DataOpentelekomcloudVpcBandwidthV2Config);
    get bandwidthType(): string;
    get chargeMode(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    get shareType(): string;
    private _size?;
    get size(): number;
    set size(value: number);
    resetSize(): void;
    get sizeInput(): number | undefined;
    get status(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
